@@ -5,7 +5,7 @@
 #' @description
 #' Function to tune a [mlr3::Learner].
 #' The function internally creates a [TuningInstanceSingleCrit] or [TuningInstanceMultiCrit] which describe the tuning problem.
-#' It executes the tuning with the [Tuner] (`method`) and returns the result with the tuning instance (`$result`).
+#' It executes the tuning with the [Tuner] (`tuner`) and returns the result with the tuning instance (`$result`).
 #' The [ArchiveTuning] (`$archive`) stores all evaluated hyperparameter configurations and performance scores.
 #'
 #' @details
@@ -17,11 +17,23 @@
 #' If no termination criterion is needed, set `term_evals`, `term_time` and `terminator` to `NULL`.
 #' The search space is created from [paradox::TuneToken] or is supplied by `search_space`.
 #'
-#' @inheritSection TuningInstanceSingleCrit Resources
+#' @section Resources:
+#' There are several sections about hyperparameter optimization in the [mlr3book](https://mlr3book.mlr-org.com).
+#'
+#'  * Simplify tuning with the [`tune()`](https://mlr3book.mlr-org.com/optimization.html#sec-simplified-tuning) function.
+#'  * Learn about [tuning spaces](https://mlr3book.mlr-org.com/technical.html#sec-tuning-space).
+#'
+#' The [gallery](https://mlr-org.com/gallery-all-optimization.html) features a collection of case studies and demos about optimization.
+#'
+#'  * Optimize an rpart classification tree with only a [few lines of code](https://mlr-org.com/gallery/optimization/2022-11-10-hyperparameter-optimization-on-the-palmer-penguins/).
+#'  * Tune an XGBoost model with [early stopping](https://mlr-org.com/gallery/optimization/2022-11-04-early-stopping-with-xgboost/).
+#'  * Make us of proven [search space](https://mlr-org.com/gallery/optimization/2021-07-06-introduction-to-mlr3tuningspaces/).
+#'  * Learn about [hotstarting](https://mlr-org.com/gallery/optimization/2023-01-16-hotstart/) models.
+#'
+#' @inheritSection TuningInstanceSingleCrit Default Measures
+#'
 #' @inheritSection ArchiveTuning Analysis
 #'
-#' @param method (`character(1)` | [Tuner])\cr
-#'  Key to retrieve tuner from [mlr_tuners] dictionary or [Tuner] object.
 #' @param measures ([mlr3::Measure] or list of [mlr3::Measure])\cr
 #'   A single measure creates a [TuningInstanceSingleCrit] and multiple measures a [TuningInstanceMultiCrit].
 #'   If `NULL`, default measure is used.
@@ -29,15 +41,16 @@
 #'  Number of allowed evaluations.
 #' @param term_time (`integer(1)`)\cr
 #'  Maximum allowed time in seconds.
-#' @param ... (named `list()`)\cr
-#'  Named arguments to be set as parameters of the tuner.
 #'
 #' @return [TuningInstanceSingleCrit] | [TuningInstanceMultiCrit]
 #'
+#' @template param_tuner
 #' @template param_task
 #' @template param_learner
 #' @template param_resampling
 #' @template param_terminator
+#' @template param_term_evals
+#' @template param_term_time
 #' @template param_search_space
 #' @template param_store_benchmark_result
 #' @template param_store_models
@@ -46,6 +59,7 @@
 #' @template param_keep_hotstart_stack
 #' @template param_evaluate_default
 #' @template param_callbacks
+#' @template param_method
 #'
 #' @export
 #' @examples
@@ -59,7 +73,7 @@
 #'
 #' # Run tuning
 #' instance = tune(
-#'   method = tnr("random_search", batch_size = 2),
+#'   tuner = tnr("random_search", batch_size = 2),
 #'   task = tsk("pima"),
 #'   learner = learner,
 #'   resampling = rsmp ("holdout"),
@@ -75,13 +89,13 @@
 #'
 #' # Inspect all evaluated configurations
 #' as.data.table(instance$archive)
-tune = function(method, task, learner, resampling, measures = NULL, term_evals = NULL, term_time = NULL, terminator = NULL, search_space = NULL, store_benchmark_result = TRUE, store_models = FALSE, check_values = FALSE, allow_hotstart = FALSE, keep_hotstart_stack = FALSE, evaluate_default = FALSE, callbacks = list(), ...) {
-  tuner = if (is.character(method)) {
-    assert_choice(method, mlr_tuners$keys())
-    tnr(method, ...)
-  } else {
-    assert_tuner(method)
+tune = function(tuner, task, learner, resampling, measures = NULL, term_evals = NULL, term_time = NULL, terminator = NULL, search_space = NULL, store_benchmark_result = TRUE, store_models = FALSE, check_values = FALSE, allow_hotstart = FALSE, keep_hotstart_stack = FALSE, evaluate_default = FALSE, callbacks = list(), method) {
+  if (!missing(method)) {
+    message("The `method` argument is deprecated and will be removed in a future release. Please use `tuner` instead.")
+    tuner = method
   }
+
+  assert_tuner(tuner)
   terminator = terminator %??% terminator_selection(term_evals, term_time)
 
   TuningInstance = if (!is.list(measures)) TuningInstanceSingleCrit else TuningInstanceMultiCrit
